=== modified file 'breezy/bzr/tests/__init__.py'
--- breezy/bzr/tests/__init__.py	2020-06-10 02:56:53 +0000
+++ breezy/bzr/tests/__init__.py	2020-06-10 03:30:11 +0000
@@ -45,24 +45,29 @@
 
     testmod_names = [
         'test_dirstate',
+        'per_bzrdir',
         'per_inventory',
         'per_pack_repository',
         'per_repository_chk',
         'per_repository_vf',
         'per_versionedfile',
+        'test__btree_serializer',
         'test__chk_map',
         'test__dirstate_helpers',
         'test__groupcompress',
+        'test_btree_index',
         'test_chk_map',
         'test_chk_serializer',
         'test_groupcompress',
         'test_knit',
+        'test_matchers',
         'test_pack',
         'test_remote',
         'test_smart',
         'test_smart_request',
         'test_smart_signals',
         'test_smart_transport',
+        'test_tags',
         'test_versionedfile',
         'test_weave',
         'test_xml',

=== renamed directory 'breezy/tests/per_bzrdir' => 'breezy/bzr/tests/per_bzrdir'
=== modified file 'breezy/bzr/tests/per_bzrdir/test_bzrdir.py'
--- breezy/tests/per_bzrdir/test_bzrdir.py	2020-03-22 18:52:18 +0000
+++ breezy/bzr/tests/per_bzrdir/test_bzrdir.py	2020-06-10 03:30:11 +0000
@@ -36,7 +36,7 @@
     TestNotApplicable,
     TestSkipped,
     )
-from breezy.tests.per_bzrdir import TestCaseWithBzrDir
+from breezy.bzr.tests.per_bzrdir import TestCaseWithBzrDir
 from breezy.transport.local import (
     LocalTransport,
     )

=== renamed file 'breezy/tests/test__btree_serializer.py' => 'breezy/bzr/tests/test__btree_serializer.py'
--- breezy/tests/test__btree_serializer.py	2018-11-11 04:08:32 +0000
+++ breezy/bzr/tests/test__btree_serializer.py	2020-06-10 03:30:11 +0000
@@ -20,8 +20,8 @@
 import binascii
 import bisect
 
-from .. import tests
-from ..sixish import (
+from ... import tests
+from ...sixish import (
     int2byte,
     )
 

=== renamed file 'breezy/tests/test_btree_index.py' => 'breezy/bzr/tests/test_btree_index.py'
--- breezy/tests/test_btree_index.py	2018-11-11 04:08:32 +0000
+++ breezy/bzr/tests/test_btree_index.py	2020-06-10 03:30:11 +0000
@@ -20,7 +20,7 @@
 import pprint
 import zlib
 
-from .. import (
+from ... import (
     errors,
     fifo_cache,
     lru_cache,
@@ -28,15 +28,15 @@
     tests,
     transport,
     )
-from ..bzr import (
+from .. import (
     btree_index,
     index as _mod_index,
     )
-from ..tests import (
+from ...tests import (
     TestCaseWithTransport,
     scenarios,
     )
-from ..tests import (
+from ...tests import (
     features,
     )
 

=== added file 'breezy/bzr/tests/test_matchers.py'
--- breezy/bzr/tests/test_matchers.py	1970-01-01 00:00:00 +0000
+++ breezy/bzr/tests/test_matchers.py	2020-06-10 03:30:11 +0000
@@ -0,0 +1,57 @@
+# Copyright (C) 2010, 2011, 2012, 2016 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests of breezy test matchers."""
+
+from testtools.matchers import *
+
+from ..smart.client import CallHookParams
+
+from ...tests import (
+    CapturedCall,
+    TestCase,
+    )
+from .matchers import *
+
+
+class TestContainsNoVfsCalls(TestCase):
+
+    def _make_call(self, method, args):
+        return CapturedCall(CallHookParams(method, args, None, None, None), 0)
+
+    def test__str__(self):
+        self.assertEqual("ContainsNoVfsCalls()", str(ContainsNoVfsCalls()))
+
+    def test_empty(self):
+        self.assertIs(None, ContainsNoVfsCalls().match([]))
+
+    def test_no_vfs_calls(self):
+        calls = [self._make_call("Branch.get_config_file", [])]
+        self.assertIs(None, ContainsNoVfsCalls().match(calls))
+
+    def test_ignores_unknown(self):
+        calls = [self._make_call("unknown", [])]
+        self.assertIs(None, ContainsNoVfsCalls().match(calls))
+
+    def test_match(self):
+        calls = [self._make_call(b"append", [b"file"]),
+                 self._make_call(b"Branch.get_config_file", [])]
+        mismatch = ContainsNoVfsCalls().match(calls)
+        self.assertIsNot(None, mismatch)
+        self.assertEqual([calls[0].call], mismatch.vfs_calls)
+        self.assertIn(mismatch.describe(), [
+            "no VFS calls expected, got: b'append'(b'file')",
+            "no VFS calls expected, got: append('file')"])

=== added file 'breezy/bzr/tests/test_tag.py'
--- breezy/bzr/tests/test_tag.py	1970-01-01 00:00:00 +0000
+++ breezy/bzr/tests/test_tag.py	2020-06-10 03:30:11 +0000
@@ -0,0 +1,45 @@
+# Copyright (C) 2007, 2009-2012, 2016 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests for breezy.bzr.tag."""
+
+
+from breezy.bzr.tag import (
+    BasicTags,
+    )
+from breezy.tests import (
+    TestCase,
+    )
+
+
+class TestTagSerialization(TestCase):
+
+    def test_tag_serialization(self):
+        """Test the precise representation of tag dicts."""
+        # Don't change this after we commit to this format, as it checks
+        # that the format is stable and compatible across releases.
+        #
+        # This release stores them in bencode as a dictionary from name to
+        # target.
+        store = BasicTags(branch=None)
+        td = dict(stable=b'stable-revid', boring=b'boring-revid')
+        packed = store._serialize_tag_dict(td)
+        expected = br'd6:boring12:boring-revid6:stable12:stable-revide'
+        self.assertEqualDiff(packed, expected)
+        self.assertEqual(store._deserialize_tag_dict(packed), td)
+
+
+

=== modified file 'breezy/tests/__init__.py'
--- breezy/tests/__init__.py	2020-06-10 02:56:53 +0000
+++ breezy/tests/__init__.py	2020-06-10 03:30:11 +0000
@@ -4001,15 +4001,18 @@
     """Return the standard list of test module names to test."""
     return [
         'breezy.bzr.tests.test_dirstate',
+        'breezy.bzr.tests.per_bzrdir',
         'breezy.bzr.tests.per_inventory',
         'breezy.bzr.tests.per_pack_repository',
         'breezy.bzr.tests.per_repository_chk',
         'breezy.bzr.tests.per_repository_vf',
         'breezy.bzr.tests.per_versionedfile',
         'breezy.bzr.tests.test_groupcompress',
+        'breezy.bzr.tests.test_btree_index',
         'breezy.bzr.tests.test_chk_map',
         'breezy.bzr.tests.test_chk_serializer',
         'breezy.bzr.tests.test_knit',
+        'breezy.bzr.tests.test_matchers',
         'breezy.bzr.tests.test_pack',
         'breezy.bzr.tests.test_remote',
         'breezy.bzr.tests.test_smart',
@@ -4017,8 +4020,10 @@
         'breezy.bzr.tests.test_smart_signals',
         'breezy.bzr.tests.test_smart_transport',
         'breezy.bzr.tests.test_versionedfile',
+        'breezy.bzr.tests.test_tag',
         'breezy.bzr.tests.test_weave',
         'breezy.bzr.tests.test_xml',
+        'breezy.bzr.tests.test__btree_serializer',
         'breezy.bzr.tests.test__chk_map',
         'breezy.bzr.tests.test__dirstate_helpers',
         'breezy.bzr.tests.test__groupcompress',
@@ -4047,7 +4052,6 @@
         'breezy.tests.blackbox',
         'breezy.tests.commands',
         'breezy.tests.per_branch',
-        'breezy.tests.per_bzrdir',
         'breezy.tests.per_controldir',
         'breezy.tests.per_controldir_colo',
         'breezy.tests.per_foreign_vcs',
@@ -4064,7 +4068,6 @@
         'breezy.tests.per_workingtree',
         'breezy.tests.test__annotator',
         'breezy.tests.test__bencode',
-        'breezy.tests.test__btree_serializer',
         'breezy.tests.test__known_graph',
         'breezy.tests.test__simple_set',
         'breezy.tests.test__static_tuple',
@@ -4077,7 +4080,6 @@
         'breezy.tests.test_bisect_multi',
         'breezy.tests.test_branch',
         'breezy.tests.test_branchbuilder',
-        'breezy.tests.test_btree_index',
         'breezy.tests.test_bugtracker',
         'breezy.tests.test_bundle',
         'breezy.tests.test_bzrdir',

=== modified file 'breezy/tests/per_interrepository/test_fetch.py'
--- breezy/tests/per_interrepository/test_fetch.py	2019-05-29 03:22:34 +0000
+++ breezy/tests/per_interrepository/test_fetch.py	2020-06-10 03:30:11 +0000
@@ -520,7 +520,7 @@
             self.assertRaises(errors.RevisionNotPresent, target.fetch, source)
         except errors.NoRoundtrippingSupport:
             raise TestNotApplicable('roundtripping not supported')
-        self.assertFalse(target.has_revision('b'))
+        self.assertFalse(target.has_revision(b'b'))
 
     def test_fetch_funky_file_id(self):
         from_tree = self.make_branch_and_tree('tree')

=== modified file 'breezy/tests/test_matchers.py'
--- breezy/tests/test_matchers.py	2019-06-29 13:16:26 +0000
+++ breezy/tests/test_matchers.py	2020-06-10 03:30:11 +0000
@@ -18,7 +18,6 @@
 
 from testtools.matchers import *
 
-from ..bzr.smart.client import CallHookParams
 from ..sixish import PY3
 
 from . import (
@@ -188,36 +187,6 @@
         self.assertIsNot(None, mismatch)
 
 
-class TestContainsNoVfsCalls(TestCase):
-
-    def _make_call(self, method, args):
-        return CapturedCall(CallHookParams(method, args, None, None, None), 0)
-
-    def test__str__(self):
-        self.assertEqual("ContainsNoVfsCalls()", str(ContainsNoVfsCalls()))
-
-    def test_empty(self):
-        self.assertIs(None, ContainsNoVfsCalls().match([]))
-
-    def test_no_vfs_calls(self):
-        calls = [self._make_call("Branch.get_config_file", [])]
-        self.assertIs(None, ContainsNoVfsCalls().match(calls))
-
-    def test_ignores_unknown(self):
-        calls = [self._make_call("unknown", [])]
-        self.assertIs(None, ContainsNoVfsCalls().match(calls))
-
-    def test_match(self):
-        calls = [self._make_call(b"append", [b"file"]),
-                 self._make_call(b"Branch.get_config_file", [])]
-        mismatch = ContainsNoVfsCalls().match(calls)
-        self.assertIsNot(None, mismatch)
-        self.assertEqual([calls[0].call], mismatch.vfs_calls)
-        self.assertIn(mismatch.describe(), [
-            "no VFS calls expected, got: b'append'(b'file')",
-            "no VFS calls expected, got: append('file')"])
-
-
 class TestRevisionHistoryMatches(TestCaseWithTransport):
 
     def test_empty(self):

=== modified file 'breezy/tests/test_tag.py'
--- breezy/tests/test_tag.py	2020-02-18 02:17:28 +0000
+++ breezy/tests/test_tag.py	2020-06-10 03:30:11 +0000
@@ -25,32 +25,12 @@
     DisabledTags,
     MemoryTags,
     )
-from breezy.bzr.tag import (
-    BasicTags,
-    )
 from breezy.tests import (
     TestCase,
     TestCaseWithTransport,
     )
 
 
-class TestTagSerialization(TestCase):
-
-    def test_tag_serialization(self):
-        """Test the precise representation of tag dicts."""
-        # Don't change this after we commit to this format, as it checks
-        # that the format is stable and compatible across releases.
-        #
-        # This release stores them in bencode as a dictionary from name to
-        # target.
-        store = BasicTags(branch=None)
-        td = dict(stable=b'stable-revid', boring=b'boring-revid')
-        packed = store._serialize_tag_dict(td)
-        expected = br'd6:boring12:boring-revid6:stable12:stable-revide'
-        self.assertEqualDiff(packed, expected)
-        self.assertEqual(store._deserialize_tag_dict(packed), td)
-
-
 class TestTagRevisionRenames(TestCaseWithTransport):
 
     def make_branch_supporting_tags(self, relpath):

